==> calendar-tools-0.1.5.tgz: package/examples/client-side/my-calendar.js <==
var today = new Date()
  , thisMonth = new Date(today.getFullYear(), today.getMonth(), 1, 10)
  , _day = 1000 * 60 * 60 * 24;

// recurring events
var events = [

      { title: 'Today - normal event'
      , start: today
      , end: new Date(+today + _day)
      , allDay: false
      }

    , { title: 'Today - normal event - all-day'
      , start: today
      , end: new Date(+today + _day)
      , allDay: true
      }

    , { title: 'Daily'
      , start: thisMonth 
      , end: new Date(+thisMonth + _day)
      , allDay: true
      , backgroundColor: '#ff66bb'
      , borderColor: '#aa6688'
      , frequency: 'day'
      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 5
          , exceptions: []
        }
      }

    , { title: 'Weekly'
      , start: new Date(+thisMonth + _day * 2)
      , end: new Date(+thisMonth + _day * 4)
      , allDay: false
      , frequency: 'week'

      , backgroundColor: '#ffaa22'
      , borderColor: '#cc9911'

      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 2
          , 'repeat-on': { m: 'on', t: 'on', f: 'on'}
          , exceptions: []
        }
      }

    , { id: 3
      , title: 'Monthly - day of month'
      , start: new Date(+thisMonth - _day * 3)
      , end: new Date(+thisMonth - _day)
      , allDay: false

      , backgroundColor: '#55bb00'
      , borderColor: '#33aa00'

      , frequency: 'month'
      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 1
          , 'repeat-on': { mode: 'day-of-month' }
          , exceptions: []
        }
      }

    , { id: 4
      , title: 'Monthly - day of week'
      , start: new Date(+thisMonth - _day * 2)
      , end: new Date(+thisMonth - _day)
      , allDay: false

      , backgroundColor: '#33aa00'
      , borderColor: '#229900'

      , frequency: 'month'
      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 1
          , 'repeat-on': { mode: 'day-of-week' }
          , exceptions: []
        }
      }

    , { title: 'Yearly'
      , start: new Date(+thisMonth + _day * 3)
      , end: new Date(+thisMonth + _day * 6)
      , allDay: false
      , frequency: 'year'
      , recurrence: {
            'end-by': {
                type: 'on'
              , on: today
            }
          , every: 1
          , exceptions: []
        }
      }

    ];


// creates Recurrence object
var Recurrence = new Carilu.Recurrence(events);

var instances = [];

$(document).ready(function() {
  $('#calendar').fullCalendar({
      editable: true
    , events: instances
    , month: 11
    , viewDisplay: function(view) {
        // getting all instances of serie
        var instances = Recurrence.getInstances(view.visStart, view.visEnd);

        $('#calendar').fullCalendar('removeEvents');
        $('#calendar').fullCalendar('addEventSource', instances);
      }

  });
  
});

==> calendar-tools-0.1.6.tgz: package/examples/client-side/my-calendar.js <==
var today = new Date()
  , thisMonth = new Date(today.getFullYear(), today.getMonth(), 1, 10)
  , _day = 1000 * 60 * 60 * 24;

// recurring events
var events = [

      { title: 'Today - normal event'
      , start: today
      , end: new Date(+today + _day)
      , allDay: false
      }

    , { title: 'Today - normal event - all-day'
      , start: today
      , end: new Date(+today + _day)
      , allDay: true
      }

    , { title: 'Daily'
      , start: thisMonth 
      , end: new Date(+thisMonth + _day)
      , allDay: true
      , backgroundColor: '#ff66bb'
      , borderColor: '#aa6688'
      , frequency: 'day'
      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 5
          , exceptions: []
        }
      }

    , { title: 'Weekly'
      , start: new Date(+thisMonth + _day * 2)
      , end: new Date(+thisMonth + _day * 4)
      , allDay: false
      , frequency: 'week'

      , backgroundColor: '#ffaa22'
      , borderColor: '#cc9911'

      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 2
          , 'repeat-on': { m: 'on', t: 'on', f: 'on'}
          , exceptions: []
        }
      }

    , { id: 3
      , title: 'Monthly - day of month'
      , start: new Date(+thisMonth - _day * 3)
      , end: new Date(+thisMonth - _day)
      , allDay: false

      , backgroundColor: '#55bb00'
      , borderColor: '#33aa00'

      , frequency: 'month'
      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 1
          , 'repeat-on': { mode: 'day-of-month' }
          , exceptions: []
        }
      }

    , { id: 4
      , title: 'Monthly - day of week'
      , start: new Date(+thisMonth - _day * 2)
      , end: new Date(+thisMonth - _day)
      , allDay: false

      , backgroundColor: '#33aa00'
      , borderColor: '#229900'

      , frequency: 'month'
      , recurrence: {
            'end-by': {
                type: 'never'
            }
          , every: 1
          , 'repeat-on': { mode: 'day-of-week' }
          , exceptions: []
        }
      }

    , { title: 'Yearly'
      , start: new Date(+thisMonth + _day * 3)
      , end: new Date(+thisMonth + _day * 6)
      , allDay: false
      , frequency: 'year'
      , recurrence: {
            'end-by': {
                type: 'on'
              , on: today
            }
          , every: 1
          , exceptions: []
        }
      }

    ];


// creates Recurrence object
var Recurrence = new caTools.Recurrence(events);

var instances = [];

$(document).ready(function() {
  $('#calendar').fullCalendar({
      editable: true
    , events: instances
    , month: 11
    , viewDisplay: function(view) {
        // getting all instances of serie
        var instances = Recurrence.getInstances(view.visStart, view.visEnd);

        $('#calendar').fullCalendar('removeEvents');
        $('#calendar').fullCalendar('addEventSource', instances);
      }

  });
  
});
